Biological Databases
====================
The following biological databases can be used for training and evaluating knowledge graph embeddings. This is done
by using the `Bio2BEL <https://github.com/bio2bel>`_ universe.

+------------------------+-----------------------+
| Source                 | DOI                   |
|                        |                       |
+========================+=======================+
| ComPath                | |compath_zenodo|      |
+------------------------+-----------------------+
| DrugBank               | |drugbank_zenodo|     |
+------------------------+-----------------------+
| HIPPIE                 | |hippie_zenodo|       |
+------------------------+-----------------------+
| KEGG                   | |kegg_zenodo|         |
+------------------------+-----------------------+
| miRTarBase             | |mirtarbase_zenodo|   |
+------------------------+-----------------------+
| MSigDB                 | |msig_zenodo|         |
+------------------------+-----------------------+
| Reactome               | |reactome_zenodo|     |
+------------------------+-----------------------+
| WikiPathways           | |wikipathways_zenodo| |
+------------------------+-----------------------+

.. |kegg_zenodo| image:: https://zenodo.org/badge/105248163.svg
    :target: https://zenodo.org/badge/latestdoi/105248163
    :alt: KEGG Zenodo DOI

.. |compath_zenodo| image:: https://zenodo.org/badge/132792765.svg
   :target: https://zenodo.org/badge/latestdoi/132792765

.. |reactome_zenodo| image:: https://zenodo.org/badge/103138323.svg
    :target: https://zenodo.org/badge/latestdoi/103138323
    :alt: Reactome Zenodo DOI

.. |wikipathways_zenodo| image:: https://zenodo.org/badge/118924155.svg
    :target: https://zenodo.org/badge/latestdoi/118924155
    :alt: WikiPathways Zenodo DOI

.. |msig_zenodo| image:: https://zenodo.org/badge/123948554.svg
    :target: https://zenodo.org/badge/latestdoi/123948554
    :alt: MSigDB Zenodo DOI

.. |drugbank_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1243727.svg
    :target: https://doi.org/10.5281/zenodo.1243727
    :alt: Zenodo DOI

.. |hippie_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1435930.svg
    :target: https://doi.org/10.5281/zenodo.1435930
    :alt: HIPPIE Zenodo DOI

.. |mirtarbase_zenodo| image:: https://zenodo.org/badge/95350968.svg
    :target: https://zenodo.org/badge/latestdoi/95350968
    :alt: Zenodo DOI
